@@ -4,7 +4,7 @@ use utf8;
 use warnings qw(all);
 
 use Benchmark::Forking qw(cmpthese);
-use Class::Load qw(load_class);
+use LWP::Protocol::Net::Curl takeover => 0;
 use LWP::UserAgent;
 
 cmpthese(10 => {
@@ -12,7 +12,7 @@ cmpthese(10 => {
         fetch();
     },
     q(LWP::Protocol::Net::Curl) => sub {
-        load_class(q(LWP::Protocol::Net::Curl));
+        LWP::Protocol::implementor(http => q(LWP::Protocol::Net::Curl));
         fetch();
     },
 });
@@ -21,11 +21,11 @@ sub fetch {
     my $ua = LWP::UserAgent->new;
     for (1 .. 1000) {
         # small file
-        $ua->get(qq(http://localhost/manual/index.html?$_));
+        $ua->get(qq(http://127.0.0.1/manual/index.html?$_));
         # average file
-        $ua->get(qq(http://localhost/manual/en/mod/mod_log_config.html?$_));
+        $ua->get(qq(http://127.0.0.1/manual/en/mod/mod_log_config.html?$_));
         # big file
-        $ua->get(qq(http://localhost/manual/en/mod/core.html?$_));
+        $ua->get(qq(http://127.0.0.1/manual/en/mod/core.html?$_));
     }
     return;
 }
